@@ -1,4 +1,5 @@
-use crate::core::{ParseError, ParseResult, ParseState, ParserMonad};
+use crate::core::ParserMonad;
+use crate::core::{ParseError, ParseResult, ParseState};
 
 pub trait ParserRunner<'a> {
   type Input;
