@@ -9,7 +9,10 @@ impl DiscardParsers for ParsersImpl {
     A: Debug + 'a, {
     Parser::new(move |parse_state| match parser.run(parse_state) {
       ParseResult::Success { length, .. } => ParseResult::successful((), length),
-      ParseResult::Failure { get, is_committed } => ParseResult::failed(get, is_committed),
+      ParseResult::Failure {
+        error,
+        committed_status: is_committed,
+      } => ParseResult::failed(error, is_committed),
     })
   }
 }
